package com.aucma.report.service.impl;

import java.util.List;
import com.aucma.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.aucma.report.mapper.BoxLastShotRecordMapper;
import com.aucma.report.domain.BoxLastShotRecord;
import com.aucma.report.service.IBoxLastShotRecordService;

/**
 * 箱体发泡注料记录报表Service业务层处理
 * 
 * @author Yinq
 * @date 2024-01-12
 */
@Service
public class BoxLastShotRecordServiceImpl implements IBoxLastShotRecordService 
{
    @Autowired
    private BoxLastShotRecordMapper boxLastShotRecordMapper;

    /**
     * 查询箱体发泡注料记录报表
     * 
     * @param objId 箱体发泡注料记录报表主键
     * @return 箱体发泡注料记录报表
     */
    @Override
    public BoxLastShotRecord selectBoxLastShotRecordByObjId(Long objId)
    {
        return boxLastShotRecordMapper.selectBoxLastShotRecordByObjId(objId);
    }

    /**
     * 查询箱体发泡注料记录报表列表
     * 
     * @param boxLastShotRecord 箱体发泡注料记录报表
     * @return 箱体发泡注料记录报表
     */
    @Override
    public List<BoxLastShotRecord> selectBoxLastShotRecordList(BoxLastShotRecord boxLastShotRecord)
    {
        return boxLastShotRecordMapper.selectBoxLastShotRecordList(boxLastShotRecord);
    }

    /**
     * 新增箱体发泡注料记录报表
     * 
     * @param boxLastShotRecord 箱体发泡注料记录报表
     * @return 结果
     */
    @Override
    public int insertBoxLastShotRecord(BoxLastShotRecord boxLastShotRecord)
    {
        boxLastShotRecord.setCreateTime(DateUtils.getNowDate());
        return boxLastShotRecordMapper.insertBoxLastShotRecord(boxLastShotRecord);
    }

    /**
     * 修改箱体发泡注料记录报表
     * 
     * @param boxLastShotRecord 箱体发泡注料记录报表
     * @return 结果
     */
    @Override
    public int updateBoxLastShotRecord(BoxLastShotRecord boxLastShotRecord)
    {
        return boxLastShotRecordMapper.updateBoxLastShotRecord(boxLastShotRecord);
    }

    /**
     * 批量删除箱体发泡注料记录报表
     * 
     * @param objIds 需要删除的箱体发泡注料记录报表主键
     * @return 结果
     */
    @Override
    public int deleteBoxLastShotRecordByObjIds(Long[] objIds)
    {
        return boxLastShotRecordMapper.deleteBoxLastShotRecordByObjIds(objIds);
    }

    /**
     * 删除箱体发泡注料记录报表信息
     * 
     * @param objId 箱体发泡注料记录报表主键
     * @return 结果
     */
    @Override
    public int deleteBoxLastShotRecordByObjId(Long objId)
    {
        return boxLastShotRecordMapper.deleteBoxLastShotRecordByObjId(objId);
    }
}
