package com.aucma.report.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.report.domain.BoxLastShotRecord;
import com.aucma.report.service.IBoxLastShotRecordService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

/**
 * 箱体发泡注料记录报表Controller
 *
 * @author Yinq
 * @date 2024-01-12
 */
@RestController
@RequestMapping("/report/lastShotRecord" )
public class BoxLastShotRecordController extends BaseController {
    @Autowired
    private IBoxLastShotRecordService boxLastShotRecordService;

    /**
     * 查询箱体发泡注料记录报表列表
     */
    @PreAuthorize("@ss.hasPermi('report:lastShotRecord:list')" )
    @GetMapping("/list" )
    public TableDataInfo list(BoxLastShotRecord boxLastShotRecord) {
        startPage();
        List<BoxLastShotRecord> list = boxLastShotRecordService.selectBoxLastShotRecordList(boxLastShotRecord);
        return getDataTable(list);
    }

    /**
     * 导出箱体发泡注料记录报表列表
     */
    @PreAuthorize("@ss.hasPermi('report:lastShotRecord:export')" )
    @Log(title = "箱体发泡注料记录报表" , businessType = BusinessType.EXPORT)
    @PostMapping("/export" )
    public void export(HttpServletResponse response, BoxLastShotRecord boxLastShotRecord) {
        List<BoxLastShotRecord> list = boxLastShotRecordService.selectBoxLastShotRecordList(boxLastShotRecord);
        ExcelUtil<BoxLastShotRecord> util = new ExcelUtil<BoxLastShotRecord>(BoxLastShotRecord. class);
        util.exportExcel(response, list, "箱体发泡注料记录报表数据" );
    }

    /**
     * 获取箱体发泡注料记录报表详细信息
     */
    @PreAuthorize("@ss.hasPermi('report:lastShotRecord:query')" )
    @GetMapping(value = "/{objId}" )
    public AjaxResult getInfo(@PathVariable("objId" ) Long objId) {
        return success(boxLastShotRecordService.selectBoxLastShotRecordByObjId(objId));
    }

    /**
     * 新增箱体发泡注料记录报表
     */
    @PreAuthorize("@ss.hasPermi('report:lastShotRecord:add')" )
    @Log(title = "箱体发泡注料记录报表" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BoxLastShotRecord boxLastShotRecord) {

        return toAjax(boxLastShotRecordService.insertBoxLastShotRecord(boxLastShotRecord));
    }

    /**
     * 修改箱体发泡注料记录报表
     */
    @PreAuthorize("@ss.hasPermi('report:lastShotRecord:edit')" )
    @Log(title = "箱体发泡注料记录报表" , businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BoxLastShotRecord boxLastShotRecord) {

        return toAjax(boxLastShotRecordService.updateBoxLastShotRecord(boxLastShotRecord));
    }

    /**
     * 删除箱体发泡注料记录报表
     */
    @PreAuthorize("@ss.hasPermi('report:lastShotRecord:remove')" )
    @Log(title = "箱体发泡注料记录报表" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}" )
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(boxLastShotRecordService.deleteBoxLastShotRecordByObjIds(objIds));
    }
}
